@@ -1,11 +1,10 @@
 package Error::Pure::HTTP;
 
-# Pragmas.
 use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 1;
 
@@ -59,17 +58,17 @@ L<https://github.com/tupinek/Error-Pure-HTTP>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2012-2015 Michal Špaček
+ © 2012-2018 Michal Josef Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
