@@ -1,11 +1,9 @@
 package Error::Pure::HTTP::Error;
 
-# Pragmas.
 use base qw(Exporter);
 use strict;
 use warnings;
 
-# Modules.
 use Error::Pure::Utils qw(err_helper);
 use Error::Pure::Output::Text qw(err_line);
 use List::MoreUtils qw(none);
@@ -16,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -79,11 +77,9 @@ Error::Pure::HTTP::Error - Error::Pure module with error on one line over HTTP.
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::HTTP::Error qw(err);
 
  # Error.
@@ -96,11 +92,9 @@ Error::Pure::HTTP::Error - Error::Pure module with error on one line over HTTP.
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::HTTP::Error qw(err);
 
  # Error.
@@ -135,17 +129,17 @@ L<https://github.com/tupinek/Error-Pure-HTTP>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2012-2015 Michal Špaček
+ © 2012-2018 Michal Josef Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
