@@ -1,11 +1,9 @@
 package Error::Pure::HTTP::ErrorList;
 
-# Pragmas.
 use base qw(Exporter);
 use strict;
 use warnings;
 
-# Modules.
 use Error::Pure::Utils qw(err_helper);
 use Error::Pure::Output::Text qw(err_line_all);
 use List::MoreUtils qw(none);
@@ -16,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -82,11 +80,9 @@ with informations over HTTP.
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::HTTP::ErrorList qw(err);
 
  # Error.
@@ -99,11 +95,9 @@ with informations over HTTP.
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::HTTP::ErrorList qw(err);
 
  # Error.
@@ -116,11 +110,9 @@ with informations over HTTP.
 
 =head1 EXAMPLE3
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use English qw(-no_match_vars);
  use Error::Pure::HTTP::ErrorList qw(err);
 
@@ -160,17 +152,17 @@ L<https://github.com/tupinek/Error-Pure>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2012-2015 Michal Špaček
+ © 2012-2018 Michal Josef Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
